pymills 3.4 Documentation — pymills 3.4.0 documentation

### Navigation

- index
- modules |
- next |
- pymills 3.4.0 documentation »

# pymills 3.4 Documentation

Release: | 3.4.0
Date: | November 20, 2013

## About

pymills is a collection of various useful Python utility modules maintained by James Mills. Some are written by James Mills while others are borrowed from other sources and attributed.

Note

You may not find this library/package useful to you as I (James Mills) don’t actively maintain this as a real project as such. It was my first ever Python Package (and the name has stuck) and I generally just throw things in it that I can find no better place for. See the API to find anything of interest.

- Visit the Project Website
- Read the Docs
- Download it from the Downloads Page

### Installation

The simplest and recommended way to install pymills is with pip. You may install the latest stable release from PyPI with pip:

    > pip install pymills

If you do not have pip, you may use easy_install:

    > easy_install pymills

Alternatively, you may download the source package from the PyPI Page or the Downloads page on the Project Website; extract it and install using:

    > python setup.py install

You can also install the latest-development version by using `pip` or `easy_install`:

    > pip install pymills==dev

or:

    > easy_install pymills==dev

For further information see the pymills documentation.

## Documentation

- API Documentation
  - pymills Package
  - ai Package
- TODO
- Road Map
- Changes
  - pymills 3.4 (2013-11-20)

## Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- pymills 3.4.0 documentation »